==> colors_format-1.0.5.tar.gz: colors_format-1.0.5/colors_format/__init__.py <==
__version__ = '1.0.5'

RED = "\033[0;31m"
GREEN = "\033[0;32m"
ORANGE = "\033[0;33m"
BLUE = "\033[0;34m"
YELLOW = "\033[0;33m"
PURPLE = "\033[0;35m"
CYAN = "\033[0;36m"
BLACK = "\033[0;30m"
RESET = '\033[0m'

red = "\033[0;31m"
green = "\033[0;32m"
orange = "\033[0;33m"
blue = "\033[0;34m"
yellow = "\033[0;33m"
purple = "\033[0;35m"
cyan = "\033[0;36m"
black = "\033[0;30m"
reset = '\033[0m'


colors = ('''
red = "\033[0;31m" 
green = "\033[0;32m"
orange = "\033[0;33m"
blue = "\033[0;34m"
yellow = "\033[0;33m"
purple = "\033[0;35m"
cyan = "\033[0;36m"
black = "\033[0;30m"
reset = '\033[0m" - Makes the text look normal
''')

# # Colors
# Red = "\033[0;31m"
# Green = "\033[0;32m"
# Orange = "\033[0;33m"
# Blue = "\033[0;34m"
# Purple = "\033[0;35m"
# Cyan = "\033[0;36m"
# White = "\033[0;37m" 
# black = "\033[0;30m"
# red = "\033[0;91m"
# green = "\033[0;92m"
# yellow = "\033[0;93m"
# blue = "\033[0;94m"
# magenta = "\033[0;95m"
# cyan = "\033[0;96m"
# bright_black = "\033[0;90m"
# bright_red = "\033[0;91m"
# bright_green = "\033[0;92m"
# bright_yellow = "\033[0;93m"
# bright_blue = "\033[0;94m"
# bright_magenta = "\033[0;95m"
# bright_cyan = "\033[0;96m"
# bright_white = "\033[0;97m"
# cyan_back = "\033[0;46m"
# purple_back = "\033[0;45m"
# white_back = "\033[0;47m"
# blue_back = "\033[0;44m"
# orange_back = "\033[0;43m"
# green_back = "\033[0;42m"
# pink_back = "\033[0;41m"
# grey_back = "\033[0;40m"
# grey = '\033[38;4;236m'
# # Formating
# bold = "\033[1m"
# underline = "\033[4m"
# italic = "\033[3m"
# darken = "\033[2m"
# invisible='\033[08m'
# reverse='\033[07m'
# reset='\033[0m'

==> colors_format-1.1.1.tar.gz: colors_format-1.1.1/colors_format/__init__.py <==
__version__ = '1.1.1'

# Deprecated
RED = "\033[0;31m"
GREEN = "\033[0;32m"
ORANGE = "\033[0;33m"
BLUE = "\033[0;34m"
YELLOW = "\033[0;33m"
PURPLE = "\033[0;35m"
CYAN = "\033[0;36m"
BLACK = "\u001b[30m"
RESET = '\033[0m'
# Deprecated

# Regular colors (Foreground)
black = "\033[0;30m"
red = "\033[0;31m"
green = "\033[0;32m"
yellow = "\033[0;33m"
blue = "\033[0;34m"
magenta = "\033[0;35m"
cyan = "\033[0;36m"
white = "\033[0;37m"

# Bright colors (Foreground)
br-black = "\033[0;90m"
br-red = "\033[0;91m"
br-green = "\033[0;92m"
br-yellow = "\033[0;93m"
br-blue = "\033[0;94m"
br-magenta = "\033[0;95m"
br-cyan = "\033[0;96m"
br-white = "\033[0;97m"

# Regular colors (Background)
bg_black = "\033[0;40m"
bg_red = "\033[0;41m"
bg_green = "\033[0;42m"
bg_yellow = "\033[0;43m"
bg_blue = "\033[0;44m"
bg_magenta = "\033[0;45m"
bg_cyan = "\033[0;46m"
bg_white = "\033[0;47m"

# Bright colors (Background)
bg_br-black = "\033[0;100m"
bg_br-red = "\033[0;101m"
bg_br-green = "\033[0;102m"
bg_br-yellow = "\033[0;103m"
bg_br-blue = "\033[0;104m"
bg_br-magenta = "\033[0;105m"
bg_br-cyan = "\033[0;106m"
bg_br-white = "\033[0;107m"

reset = '\033[0m'

# # Colors
# Red = "\033[0;31m"
# Green = "\033[0;32m"
# Orange = "\033[0;33m"
# Blue = "\033[0;34m"
# Purple = "\033[0;35m"
# Cyan = "\033[0;36m"
# White = "\033[0;37m" 
# black = "\033[0;30m"
# red = "\033[0;91m"
# green = "\033[0;92m"
# yellow = "\033[0;93m"
# blue = "\033[0;94m"
# magenta = "\033[0;95m"
# cyan = "\033[0;96m"
# bright_black = "\033[0;90m"
# bright_red = "\033[0;91m"
# bright_green = "\033[0;92m"
# bright_yellow = "\033[0;93m"
# bright_blue = "\033[0;94m"
# bright_magenta = "\033[0;95m"
# bright_cyan = "\033[0;96m"
# bright_white = "\033[0;97m"
# cyan_back = "\033[0;46m"
# purple_back = "\033[0;45m"
# white_back = "\033[0;47m"
# blue_back = "\033[0;44m"
# orange_back = "\033[0;43m"
# green_back = "\033[0;42m"
# pink_back = "\033[0;41m"
# grey_back = "\033[0;40m"
# grey = '\033[38;4;236m'
# # Formating
# bold = "\033[1m"
# underline = "\033[4m"
# italic = "\033[3m"
# darken = "\033[2m"
# invisible='\033[08m'
# reverse='\033[07m'
# reset='\033[0m'
